calc_F: Mean Fecundity F

View source: R/lifetable_indicators.R

calc_FR Documentation

Mean Fecundity F

Description

The mean fecundity of the females of the cohort: the total number of eggs laid by all females divided by the number of females, F = (total number of eggs) / (number of females).

Usage

calc_F(lt)

Arguments

lt

A life_table object returned by lifeTable_read.

Value

A single numeric value: the mean number of eggs per female.

See Also

calc_fxj for the age-specific fecundity.

Examples

f <- system.file("extdata", "lifetable_example.csv", package = "insectecol")
lt <- lifeTable_read(f)
calc_F(lt)

insectecol documentation built on Oct. 5, 2026, 5:08 p.m.