calc_N: Cohort Size N

View source: R/lifetable_indicators.R

calc_NR Documentation

Cohort Size N

Description

The number of individuals in the raw data set, i.e. the number of newly hatched eggs with which the cohort started. All survival rates of the age-stage, two-sex life table are expressed as proportions of this cohort size.

Usage

calc_N(lt)

Arguments

lt

A life_table object returned by lifeTable_read.

Value

A single numeric value: the number of data rows.

References

Chi, H. (1988) Life-table analysis incorporating both sexes and variable development rates among individuals. Environmental Entomology 17(1), 26-34.

See Also

lifeTable_calculate_all computes all parameters at once.

Examples

f <- system.file("extdata", "lifetable_example.csv", package = "insectecol")
lt <- lifeTable_read(f)
calc_N(lt)

insectecol documentation built on Oct. 5, 2026, 5:08 p.m.