calc_ex: Life Expectancy e_x

View source: R/lifetable_indicators.R

calc_exR Documentation

Life Expectancy e_x

Description

The life expectancy of the individuals that have reached age x, calculated as the cumulative sum of the age-specific survival rates from age x to the end of the life table, e_x = sum over y >= x of l_y.

Usage

calc_ex(lt, lx = NULL)

Arguments

lt

A life_table object returned by lifeTable_read.

lx

Optional; the result of calc_lx. Supplying it avoids recomputing.

Value

A data frame with the columns Age and e_x; one row per age class.

References

Chi, H. and Liu, H. (1985) Two new methods for the study of insect population ecology. Bulletin of the Institute of Zoology, Academia Sinica 24(2), 225-240.

See Also

calc_lx

Examples

f <- system.file("extdata", "lifetable_example.csv", package = "insectecol")
lt <- lifeTable_read(f)
head(calc_ex(lt))

insectecol documentation built on Oct. 5, 2026, 5:08 p.m.