View source: R/lifetable_indicators.R
| calc_F | R Documentation |
The mean fecundity of the females of the cohort: the total number of
eggs laid by all females divided by the number of females,
F = (total number of eggs) / (number of females).
calc_F(lt)
lt |
A |
A single numeric value: the mean number of eggs per female.
calc_fxj for the age-specific fecundity.
f <- system.file("extdata", "lifetable_example.csv", package = "insectecol")
lt <- lifeTable_read(f)
calc_F(lt)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.