View source: R/lifetable_indicators.R
| calc_N | R Documentation |
The number of individuals in the raw data set, i.e. the number of newly hatched eggs with which the cohort started. All survival rates of the age-stage, two-sex life table are expressed as proportions of this cohort size.
calc_N(lt)
lt |
A |
A single numeric value: the number of data rows.
Chi, H. (1988) Life-table analysis incorporating both sexes and variable development rates among individuals. Environmental Entomology 17(1), 26-34.
lifeTable_calculate_all computes all parameters at once.
f <- system.file("extdata", "lifetable_example.csv", package = "insectecol")
lt <- lifeTable_read(f)
calc_N(lt)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.