View source: R/lifetable_indicators.R
| calc_R0 | R Documentation |
The net reproductive rate: the expected number of eggs produced by an
average individual of the cohort over its whole life,
R0 = sum over x of s_x,Female * F_xj. A population with
R0 = 1 exactly replaces itself; R0 > 1 indicates growth
and R0 < 1 decline.
calc_R0(lt, sxj = NULL, fxj = NULL)
lt |
A |
sxj |
Optional; the result of |
fxj |
Optional; the result of |
A single numeric value: the net reproductive rate R0.
Goodman, D. (1982) Optimal life histories, optimal notation, and the value of reproductive value. The American Naturalist 119(6), 803-823.
calc_T, lifeTable_calculate_all
f <- system.file("extdata", "lifetable_example.csv", package = "insectecol")
lt <- lifeTable_read(f)
calc_R0(lt)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.