View source: R/lifetable_indicators.R
| calc_T | R Documentation |
The mean generation time, calculated as T = log(R0) / r: the
time needed for the population to grow to an R0-fold of its
current size when increasing at the constant rate r.
calc_T(lt, R0 = NULL, r = NULL)
lt |
A |
R0 |
Optional; the result of |
r |
Optional; the result of |
A single numeric value: the mean generation time T (days).
Goodman, D. (1982) Optimal life histories, optimal notation, and the value of reproductive value. The American Naturalist 119(6), 803-823.
calc_R0, calc_r
f <- system.file("extdata", "lifetable_example.csv", package = "insectecol")
lt <- lifeTable_read(f)
calc_T(lt)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.