View source: R/lifetable_indicators.R
| calc_ex | R Documentation |
The life expectancy of the individuals that have reached age x,
calculated as the cumulative sum of the age-specific survival rates
from age x to the end of the life table,
e_x = sum over y >= x of l_y.
calc_ex(lt, lx = NULL)
lt |
A |
lx |
Optional; the result of |
A data frame with the columns Age and e_x; one
row per age class.
Chi, H. and Liu, H. (1985) Two new methods for the study of insect population ecology. Bulletin of the Institute of Zoology, Academia Sinica 24(2), 225-240.
calc_lx
f <- system.file("extdata", "lifetable_example.csv", package = "insectecol")
lt <- lifeTable_read(f)
head(calc_ex(lt))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.