View source: R/lifetable_indicators.R
| calc_lx | R Documentation |
The proportion of the original cohort that is still alive at age x,
obtained by summing the age-stage survival rates over all stages:
l_x = sum over j of s_xj.
calc_lx(lt, sxj = NULL)
lt |
A |
sxj |
Optional; the result of |
A data frame with the columns Age and l_x; a
terminal row with l_x = 0 is appended so that the survival
curve ends at zero.
Chi, H. (1988) Life-table analysis incorporating both sexes and variable development rates among individuals. Environmental Entomology 17(1), 26-34.
calc_sxj, calc_mx
f <- system.file("extdata", "lifetable_example.csv", package = "insectecol")
lt <- lifeTable_read(f)
head(calc_lx(lt))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.