View source: R/lifetable_indicators.R
| calc_mx | R Documentation |
The age-specific fecundity of the cohort, computed from the female
age-stage survival rate, the age-specific female fecundity and the
overall survival rate: m_x = s_x,Female * F_xj / l_x. With this
definition sum(l_x * m_x) equals the net reproductive rate
calc_R0, so the Euler-Lotka equation solved by
calc_r is consistent.
calc_mx(lt, sxj = NULL, fxj = NULL, lx = NULL)
lt |
A |
sxj |
Optional; the result of |
fxj |
Optional; the result of |
lx |
Optional; the result of |
A data frame with the columns Age and m_x; a
terminal row with m_x = 0 is appended.
Chi, H. and Liu, H. (1985) Two new methods for the study of insect population ecology. Bull. Inst. Zool. Acad. Sin 24(2), 225-240.
calc_fxj, calc_lx, calc_r
f <- system.file("extdata", "lifetable_example.csv", package = "insectecol")
lt <- lifeTable_read(f)
head(calc_mx(lt))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.