View source: R/emergence_read.R
| emergence_read | R Documentation |
Reads one field survey of the population stage structure for
emergence_calc: one row per stage, with a stage
name column, a count (or percent) column and a days-to-eclosion
column. The input may be a single csv file (delimiter
auto-detected), a single xlsx/xls file (via the 'readxl' package)
or a folder containing csv/xlsx files (batch mode; the files are
combined and the source file name kept in a source_file
column).
emergence_read(
path,
encoding = "UTF-8",
header = TRUE,
pattern = "\\.(csv|xlsx|xls)$"
)
path |
Path to a csv/xlsx file or to a folder (batch mode). |
encoding |
Text encoding of csv files, default |
header |
Logical; whether the file(s) contain a header row. Default TRUE. |
pattern |
Regular expression selecting the files in batch mode; default: csv / xlsx / xls. |
A data.frame (single file), or the combined data.frame with
an extra source_file column (folder input).
emergence_calc,
emergence_analyze
f <- system.file("extdata", "emergence_example.csv",
package = "insectecol")
d <- emergence_read(f)
head(d)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.