| gdd_daily | R Documentation |
Accumulates daily degree-days above the developmental threshold temperature, useful for predicting field phenology (e.g. the date on which a stage completes its effective accumulated temperature K).
gdd_daily(Tmin, Tmax, C, method = c("avg", "triangle"))
Tmin, Tmax |
Numeric vectors of daily minimum / maximum temperatures (deg C). |
C |
Developmental threshold temperature (deg C), e.g. taken
from a |
method |
|
A list with daily, cumulative and total.
gdd_daily(c(8, 10, 12), c(20, 22, 25), C = 11)$total
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.